Diagnostics class

Constructors

Diagnostics({String? code, String? severity, String? type, Location? location, String? problemMessage, String? correctionMessage, String? documentation})
Diagnostics.fromJson(Map<String, dynamic> json)

Properties

code ↔ String?
getter/setter pair
correctionMessage ↔ String?
getter/setter pair
documentation ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
location ↔ Location?
getter/setter pair
problemMessage ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
severity ↔ String?
getter/setter pair
type ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited