TestIDError class

Constructors

TestIDError({int? testID, String? error, String? stackTrace, bool? isFailure, String? type, int? time})
TestIDError.fromJson(Map<String, dynamic> json)

Properties

error ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isFailure ↔ bool?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackTrace ↔ String?
getter/setter pair
testID ↔ int?
getter/setter pair
time ↔ int?
getter/setter pair
type ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited