TestReport class

Constructors

TestReport({required String testName, required String testFilePath, required String result, required String error, required String message})

Properties

error → String
final
hashCode → int
The hash code for this object.
no setterinherited
message → String
final
result → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
testFilePath → String
final
testName → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited